@@ -3,7 +3,7 @@ package Acme::Alien::DontPanic;
 use strict;
 use warnings;
 
-our $VERSION = '0.029';
+our $VERSION = '0.030';
 $VERSION = eval $VERSION;
 
 use parent 'Alien::Base';
@@ -42,7 +42,7 @@ L<Acme::Ford::Prefect>
 
 =head1 SOURCE REPOSITORY
 
-L<http://github.com/jberger/Alien-Base-Extras>
+L<http://github.com/Perl5-Alien/Acme-Alien-DontPanic>
 
 =head1 AUTHOR
 
